/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

function TableCDNDeliveryServicesController(cdn, deliveryServices, steeringTargets, filter, $controller, $scope) {

	// extends the TableDeliveryServicesController to inherit common methods
	angular.extend(this, $controller('TableDeliveryServicesController', { tableName: 'cdnDS', deliveryServices: deliveryServices, steeringTargets: steeringTargets, filter: filter, $scope: $scope }));

	$scope.cdn = cdn;
	$scope.breadCrumbs = [
		{
			href: "#!/cdns",
			text: "CDNs"
		},
		{
			href: `#!/cdns/${cdn.id}`,
			text: cdn.name
		},
		{
			text: "Delivery Services"
		}
	];
};

TableCDNDeliveryServicesController.$inject = ['cdn', 'deliveryServices', 'steeringTargets', 'filter', '$controller', '$scope'];
module.exports = TableCDNDeliveryServicesController;
